@@ -41,7 +41,7 @@ def submissions(db):
     db.add(a)
     db.commit()
 
-    s = api.Student(id="12345", first_name='Jane', last_name='Doe', email='janedoe@nowhere')
+    s = api.Student(id="12345", first_name='Jane', last_name='Doe', email='janedoe@nowhere', lms_user_id='230')
     sa = api.SubmittedAssignment(assignment=a, student=s)
     sn = api.SubmittedNotebook(assignment=sa, notebook=n)
     g1a = api.Grade(cell=gc1, notebook=sn)
@@ -51,7 +51,7 @@ def submissions(db):
     db.add(s)
     db.commit()
 
-    s = api.Student(id="6789", first_name='John', last_name='Doe', email='johndoe@nowhere')
+    s = api.Student(id="6789", first_name='John', last_name='Doe', email='johndoe@nowhere', lms_user_id='230')
     sa = api.SubmittedAssignment(assignment=a, student=s)
     sn = api.SubmittedNotebook(assignment=sa, notebook=n)
     g1b = api.Grade(cell=gc1, notebook=sn)
@@ -146,6 +146,8 @@ def test_create_solution_cell(db):
     assert s.comments == []
     assert n.solution_cells == [s]
 
+    assert repr(s) == "SolutionCell<foo/blah/foo>"
+
 
 def test_create_source_cell(db):
     now = datetime.datetime.utcnow()
@@ -167,7 +169,7 @@ def test_create_source_cell(db):
     assert s.notebook == n
     assert n.source_cells == [s]
 
-    assert repr(s) == "SolutionCell<foo/blah/foo>"
+    assert repr(s) == "SourceCell<foo/blah/foo>"
 
 
 def test_create_student(db):
@@ -209,9 +211,9 @@ def test_create_submitted_assignment(db):
     assert sa.max_written_score == 0
     assert not sa.needs_manual_grade
 
-    assert sa.duedate == None
-    assert sa.timestamp == None
-    assert sa.extension == None
+    assert sa.duedate is None
+    assert sa.timestamp is None
+    assert sa.extension is None
     assert sa.total_seconds_late == 0
 
     d = sa.to_dict()
@@ -242,7 +244,7 @@ def test_submission_timestamp_ontime(db):
 
     assert sa.duedate == duedate
     assert sa.timestamp == timestamp
-    assert sa.extension == None
+    assert sa.extension is None
     assert sa.total_seconds_late == 0
 
 
@@ -258,7 +260,7 @@ def test_submission_timestamp_late(db):
 
     assert sa.duedate == duedate
     assert sa.timestamp == timestamp
-    assert sa.extension == None
+    assert sa.extension is None
     assert sa.total_seconds_late == 172800
 
 
@@ -348,7 +350,7 @@ def test_create_code_grade(db):
     assert g.cell == gc
     assert g.notebook == sn
     assert g.auto_score == 5
-    assert g.manual_score == None
+    assert g.manual_score is None
     assert g.assignment == sa
     assert g.student == s
     assert g.max_score == 10
@@ -407,8 +409,8 @@ def test_create_written_grade(db):
     assert g.id
     assert g.cell == gc
     assert g.notebook == sn
-    assert g.auto_score == None
-    assert g.manual_score == None
+    assert g.auto_score is None
+    assert g.manual_score is None
     assert g.assignment == sa
     assert g.student == s
     assert g.max_score == 10
@@ -473,6 +475,7 @@ def test_create_comment(db):
 
     assert repr(c) == "Comment<foo/blah/foo for 12345>"
 
+
 def test_query_needs_manual_grade_ungraded(submissions):
     db = submissions[0]
 
@@ -517,6 +520,7 @@ def test_query_needs_manual_grade_ungraded(submissions):
         .all()
     assert a == b
 
+
 def test_query_needs_manual_grade_autograded(submissions):
     db, grades, _ = submissions
 
@@ -590,6 +594,7 @@ def test_query_needs_manual_grade_autograded(submissions):
         .filter(api.SubmittedNotebook.needs_manual_grade)\
         .all()
 
+
 def test_query_needs_manual_grade_manualgraded(submissions):
     db, grades, _ = submissions
 
@@ -664,6 +669,7 @@ def test_query_needs_manual_grade_manualgraded(submissions):
         .filter(api.SubmittedNotebook.needs_manual_grade)\
         .all()
 
+
 def test_query_max_score(submissions):
     db = submissions[0]
 
@@ -675,6 +681,7 @@ def test_query_max_score(submissions):
     assert [15, 15] == sorted([x[1] for x in db.query(api.SubmittedAssignment.id, api.SubmittedAssignment.max_score).all()])
     assert [15, 15] == sorted([x[1] for x in db.query(api.Student.id, api.Student.max_score).all()])
 
+
 def test_query_score_ungraded(submissions):
     db = submissions[0]
 
@@ -683,11 +690,13 @@ def test_query_score_ungraded(submissions):
     assert [x[1] for x in db.query(api.SubmittedAssignment.id, api.SubmittedAssignment.score).all()] == [0.0, 0.0]
     assert [x[1] for x in db.query(api.Student.id, api.Student.score).all()] == [0.0, 0.0]
 
+
 def test_query_comment_unchanged(submissions):
     db = submissions[0]
 
     assert [x[0] for x in db.query(api.Comment.comment).all()] == [None, None]
 
+
 def test_query_score_autograded(submissions):
     db, grades, _ = submissions
 
@@ -702,6 +711,7 @@ def test_query_score_autograded(submissions):
     assert sorted(x[1] for x in db.query(api.SubmittedAssignment.id, api.SubmittedAssignment.score).all()) == [7.5, 10]
     assert sorted(x[1] for x in db.query(api.Student.id, api.Student.score).all()) == [7.5, 10]
 
+
 def test_query_auto_comment(submissions):
     db, _, comments = submissions
 
@@ -711,6 +721,7 @@ def test_query_auto_comment(submissions):
 
     assert sorted(x[0] for x in db.query(api.Comment.comment).all()) == ["bar", "foo"]
 
+
 def test_query_score_manualgraded(submissions):
     db, grades, _ = submissions
 
@@ -729,6 +740,7 @@ def test_query_score_manualgraded(submissions):
     assert sorted(x[1] for x in db.query(api.SubmittedAssignment.id, api.SubmittedAssignment.score).all()) == [5.5, 12]
     assert sorted(x[1] for x in db.query(api.Student.id, api.Student.score).all()) == [5.5, 12]
 
+
 def test_query_manual_comment(submissions):
     db, _, comments = submissions
 
@@ -740,6 +752,7 @@ def test_query_manual_comment(submissions):
 
     assert sorted(x[0] for x in db.query(api.Comment.comment).all()) == ["baz", "quux"]
 
+
 def test_query_max_written_score(submissions):
     db = submissions[0]
 
@@ -748,12 +761,14 @@ def test_query_max_written_score(submissions):
     assert [10] == sorted([x[1] for x in db.query(api.Assignment.id, api.Assignment.max_written_score).all()])
     assert [10, 10] == sorted([x[1] for x in db.query(api.SubmittedAssignment.id, api.SubmittedAssignment.max_written_score).all()])
 
+
 def test_query_written_score_ungraded(submissions):
     db = submissions[0]
 
     assert [0.0, 0.0] == [x[1] for x in db.query(api.SubmittedNotebook.id, api.SubmittedNotebook.written_score).all()]
     assert [0.0, 0.0] == [x[1] for x in db.query(api.SubmittedAssignment.id, api.SubmittedAssignment.written_score).all()]
 
+
 def test_query_written_score_autograded(submissions):
     db, grades, _ = submissions
 
@@ -766,6 +781,7 @@ def test_query_written_score_autograded(submissions):
     assert [5, 10] == sorted(x[1] for x in db.query(api.SubmittedNotebook.id, api.SubmittedNotebook.written_score).all())
     assert [5, 10] == sorted(x[1] for x in db.query(api.SubmittedAssignment.id, api.SubmittedAssignment.written_score).all())
 
+
 def test_query_written_score_manualgraded(submissions):
     db, grades, _ = submissions
 
@@ -782,6 +798,7 @@ def test_query_written_score_manualgraded(submissions):
     assert [4, 9] == sorted(x[1] for x in db.query(api.SubmittedNotebook.id, api.SubmittedNotebook.written_score).all())
     assert [4, 9] == sorted(x[1] for x in db.query(api.SubmittedAssignment.id, api.SubmittedAssignment.written_score).all())
 
+
 def test_query_max_code_score(submissions):
     db = submissions[0]
 
@@ -790,12 +807,14 @@ def test_query_max_code_score(submissions):
     assert [5] == sorted([x[1] for x in db.query(api.Assignment.id, api.Assignment.max_code_score).all()])
     assert [5, 5] == sorted([x[1] for x in db.query(api.SubmittedAssignment.id, api.SubmittedAssignment.max_code_score).all()])
 
+
 def test_query_code_score_ungraded(submissions):
     db = submissions[0]
 
     assert [0.0, 0.0] == [x[1] for x in db.query(api.SubmittedNotebook.id, api.SubmittedNotebook.code_score).all()]
     assert [0.0, 0.0] == [x[1] for x in db.query(api.SubmittedAssignment.id, api.SubmittedAssignment.code_score).all()]
 
+
 def test_query_code_score_autograded(submissions):
     db, grades, _ = submissions
 
@@ -808,6 +827,7 @@ def test_query_code_score_autograded(submissions):
     assert [0, 2.5] == sorted(x[1] for x in db.query(api.SubmittedNotebook.id, api.SubmittedNotebook.code_score).all())
     assert [0, 2.5] == sorted(x[1] for x in db.query(api.SubmittedAssignment.id, api.SubmittedAssignment.code_score).all())
 
+
 def test_query_code_score_manualgraded(submissions):
     db, grades, _ = submissions
 
@@ -824,6 +844,7 @@ def test_query_code_score_manualgraded(submissions):
     assert [1.5, 3] == sorted(x[1] for x in db.query(api.SubmittedNotebook.id, api.SubmittedNotebook.code_score).all())
     assert [1.5, 3] == sorted(x[1] for x in db.query(api.SubmittedAssignment.id, api.SubmittedAssignment.code_score).all())
 
+
 def test_query_auto_score_extra_credit(submissions):
     db, grades, _ = submissions
 
@@ -843,6 +864,7 @@ def test_query_auto_score_extra_credit(submissions):
     assert sorted(x[1] for x in db.query(api.SubmittedAssignment.id, api.SubmittedAssignment.score).all()) == [10.5, 10.9]
     assert sorted(x[1] for x in db.query(api.Student.id, api.Student.score).all()) == [10.5, 10.9]
 
+
 def test_query_manual_score_extra_credit(submissions):
     db, grades, _ = submissions
 
@@ -867,12 +889,14 @@ def test_query_manual_score_extra_credit(submissions):
     assert sorted(x[1] for x in db.query(api.SubmittedAssignment.id, api.SubmittedAssignment.score).all()) == [6, 15.4]
     assert sorted(x[1] for x in db.query(api.Student.id, api.Student.score).all()) == [6, 15.4]
 
+
 def test_query_num_submissions(submissions):
     db = submissions[0]
 
     assert [2] == [x[0] for x in db.query(api.Assignment.num_submissions).all()]
     assert [2] == [x[0] for x in db.query(api.Notebook.num_submissions).all()]
 
+
 def test_student_max_score(db):
     now = datetime.datetime.utcnow()
     a = api.Assignment(name='foo', duedate=now)
@@ -888,6 +912,7 @@ def test_student_max_score(db):
 
     assert s.max_score == 15
 
+
 def test_query_grade_cell_types(submissions):
     db = submissions[0]
 
@@ -913,6 +938,7 @@ def test_query_grade_cell_types(submissions):
         .all()
     assert a == b
 
+
 def test_query_failed_tests_failed(submissions):
     db, grades, _ = submissions
 
@@ -941,6 +967,7 @@ def test_query_failed_tests_failed(submissions):
         .order_by(api.SubmittedNotebook.id)\
         .all()
 
+
 def test_query_failed_tests_ok(submissions):
     db, all_grades, _ = submissions
 
@@ -968,7 +995,7 @@ def test_assignment_to_dict(submissions):
 
     assert set(ad.keys()) == {
         'id', 'name', 'duedate', 'num_submissions', 'max_score',
-        'max_code_score', 'max_written_score'}
+        'max_code_score', 'max_written_score', 'max_task_score'}
 
     assert ad['id'] == a.id
     assert ad['name'] == "foo"
@@ -991,7 +1018,7 @@ def test_notebook_to_dict(submissions):
 
     assert set(nd.keys()) == {
         'id', 'name', 'num_submissions', 'max_score', 'max_code_score',
-        'max_written_score', 'needs_manual_grade'}
+        'max_written_score', 'needs_manual_grade', 'max_task_score'}
 
     assert nd['id'] == n.id
     assert nd['name'] == 'blah'
@@ -1102,7 +1129,7 @@ def test_student_to_dict(submissions):
 
     assert set(s1d.keys()) == set(s2d.keys())
     assert set(s1d.keys()) == {
-        'id', 'first_name', 'last_name', 'email', 'score', 'max_score'}
+        'id', 'first_name', 'last_name', 'email', 'score', 'max_score', 'lms_user_id'}
 
     assert s1d['id'] == '12345'
     assert s1d['first_name'] == 'Jane'
@@ -1110,6 +1137,7 @@ def test_student_to_dict(submissions):
     assert s1d['email'] == 'janedoe@nowhere'
     assert s1d['score'] == 0
     assert s1d['max_score'] == 15
+    assert s1d['lms_user_id'] == '230'
 
     assert s2d['id'] == '6789'
     assert s2d['first_name'] == 'John'
@@ -1117,6 +1145,7 @@ def test_student_to_dict(submissions):
     assert s2d['email'] == 'johndoe@nowhere'
     assert s2d['score'] == 0
     assert s2d['max_score'] == 15
+    assert s2d['lms_user_id'] == '230'
 
     # make sure it can be JSONified
     json.dumps(s1d)
@@ -1136,6 +1165,7 @@ def test_submittedassignment_to_dict(submissions):
     assert set(sad.keys()) == {
         'id', 'name', 'student', 'timestamp', 'score', 'max_score', 'code_score',
         'max_code_score', 'written_score', 'max_written_score',
+        'task_score', 'max_task_score',
         'needs_manual_grade', 'last_name', 'first_name'}
 
     assert sad['id'] == sa.id
@@ -1172,6 +1202,7 @@ def test_submittednotebook_to_dict(submissions):
         'id', 'name', 'student', 'last_name', 'first_name',
         'score', 'max_score', 'code_score',
         'max_code_score', 'written_score', 'max_written_score',
+        'task_score', 'max_task_score',
         'needs_manual_grade', 'failed_tests', 'flagged'}
 
     assert snd['id'] == sn.id
