@@ -50,7 +50,7 @@ for (dirname, dirnames, filenames) in os.walk("nbgrader/alembic"):
         alembic_files.append(os.path.join(root, filename))
 
 
-name = 'nbgrader'
+name = u'nbgrader'
 here = os.path.abspath(os.path.dirname(__file__))
 version_ns = {}
 with open(os.path.join(here, name, '_version.py')) as f:
@@ -71,8 +71,8 @@ setup_args = dict(
         'Programming Language :: Python :: 2',
         'Programming Language :: Python :: 2.7',
         'Programming Language :: Python :: 3',
-        'Programming Language :: Python :: 3.4',
         'Programming Language :: Python :: 3.5',
+        'Programming Language :: Python :: 3.6',
     ],
     packages=find_packages(),
     package_data={
@@ -93,17 +93,19 @@ setup_args = dict(
         "python-dateutil",
         "jupyter",
         "notebook>=4.2",
-        "nbconvert>=4.2",
+        "nbconvert>=5.6",
         "nbformat",
         "traitlets",
         "jupyter_core",
         "jupyter_client",
         "tornado",
-        "six>=1.9",
+        "six>=1.11",  # jsonschema needs >=1.11
         "requests",
         "jsonschema",
-        "alembic"
+        "alembic",
+        "fuzzywuzzy"
     ]
 )
 
-setup(**setup_args)
+if __name__ == "__main__":
+    setup(**setup_args)
